Mopidy-Yandexmusic
******************

`Mopidy <http://www.mopidy.com/>`_ extension for playing music from
`Yandex.Music <http://music.yandex.ru/>`_.


Installation
============

Install by running::

    sudo pip install Mopidy-Yandexmusic


Configuration
=============

Before starting Mopidy, you must add your Yandex.Music username and password
to the Mopidy configuration file::

    [yandexmusic]
    login = alice
    password = secret
    bitrate = 192 ; Preffered bitrate, default 192 kbps





Changelog
=========

v0.0.1 (2020-05-18)
-------------------

- Initial release.

v0.0.2 (2020-12-1)
-------------------
- Added preffered bitrate to Mopidy configuration
- Playlists, generated by Yandex:
    - Daily generated playlist
    - Playlist with Alice
    - "Dejavu" playlist

v0.0.6 (2020-12-1)
-------------------
- Added info about artists